This is the mail archive of the gdb-patches@sourceware.org mailing list for the GDB project.


Index Nav: [Date Index] [Subject Index] [Author Index] [Thread Index]
Message Nav: [Date Prev] [Date Next] [Thread Prev] [Thread Next]
Other format: [Raw text]

[reverse RFA] Change the name of record


Change name to make it clear.

2008-09-24  Hui Zhu  <teawater@gmail.com>

	* i386-tdep.c, inflow.c, infrun.c, linux-record.c,
	linux-record.h, record.c, record.h: Change name from
	"record and reverse target" to
	"process record and reply target".
--- a/ChangeLog
+++ b/ChangeLog
@@ -1,3 +1,10 @@
+2008-09-24  Hui Zhu  <teawater@gmail.com>
+
+	* i386-tdep.c, inflow.c, infrun.c, linux-record.c,
+	linux-record.h, record.c, record.h: Change name from
+	"record and reverse target" to
+	"process record and reply target".
+
 2008-09-19  Hui Zhu  <teawater@gmail.com>
 
 	* record.c (record_wait): Fix the bug of forware step after
--- a/i386-tdep.c
+++ b/i386-tdep.c
@@ -2595,7 +2595,7 @@ i386_record_modrm (void)
 {
   if (target_read_memory (i386_record_pc, &modrm, 1))
     {
-      printf_unfiltered (_("Record: read memeory 0x%s error.\n"),
+      printf_unfiltered (_("Process record: read memeory 0x%s error.\n"),
 			 paddr_nz (i386_record_pc));
       return (-1);
     }
@@ -2631,7 +2631,7 @@ i386_record_lea_modrm_addr (uint32_t * a
 	  havesib = 1;
 	  if (target_read_memory (i386_record_pc, &tmpu8, 1))
 	    {
-	      printf_unfiltered (_("Record: read memeory 0x%s error.\n"),
+	      printf_unfiltered (_("Process record: read memeory 0x%s error.\n"),
 				 paddr_nz (i386_record_pc));
 	      return (-1);
 	    }
@@ -2649,7 +2649,7 @@ i386_record_lea_modrm_addr (uint32_t * a
 	      base = 0xff;
 	      if (target_read_memory (i386_record_pc, (gdb_byte *) addr, 4))
 		{
-		  printf_unfiltered (_("Record: read memeory 0x%s error.\n"),
+		  printf_unfiltered (_("Process record: read memeory 0x%s error.\n"),
 				     paddr_nz (i386_record_pc));
 		  return (-1);
 		}
@@ -2663,7 +2663,7 @@ i386_record_lea_modrm_addr (uint32_t * a
 	case 1:
 	  if (target_read_memory (i386_record_pc, &tmpu8, 1))
 	    {
-	      printf_unfiltered (_("Record: read memeory 0x%s error.\n"),
+	      printf_unfiltered (_("Process record: read memeory 0x%s error.\n"),
 				 paddr_nz (i386_record_pc));
 	      return (-1);
 	    }
@@ -2673,7 +2673,7 @@ i386_record_lea_modrm_addr (uint32_t * a
 	case 2:
 	  if (target_read_memory (i386_record_pc, (gdb_byte *) addr, 4))
 	    {
-	      printf_unfiltered (_("Record: read memeory 0x%s error.\n"),
+	      printf_unfiltered (_("Process record: read memeory 0x%s error.\n"),
 				 paddr_nz (i386_record_pc));
 	      return (-1);
 	    }
@@ -2705,7 +2705,7 @@ i386_record_lea_modrm_addr (uint32_t * a
 	      if (target_read_memory
 		  (i386_record_pc, (gdb_byte *) & tmpu16, 2))
 		{
-		  printf_unfiltered (_("Record: read memeory 0x%s error.\n"),
+		  printf_unfiltered (_("Process record: read memeory 0x%s error.\n"),
 				     paddr_nz (i386_record_pc));
 		  return (-1);
 		}
@@ -2722,7 +2722,7 @@ i386_record_lea_modrm_addr (uint32_t * a
 	case 1:
 	  if (target_read_memory (i386_record_pc, &tmpu8, 1))
 	    {
-	      printf_unfiltered (_("Record: read memeory 0x%s error.\n"),
+	      printf_unfiltered (_("Process record: read memeory 0x%s error.\n"),
 				 paddr_nz (i386_record_pc));
 	      return (-1);
 	    }
@@ -2732,7 +2732,7 @@ i386_record_lea_modrm_addr (uint32_t * a
 	case 2:
 	  if (target_read_memory (i386_record_pc, (gdb_byte *) & tmpu16, 2))
 	    {
-	      printf_unfiltered (_("Record: read memeory 0x%s error.\n"),
+	      printf_unfiltered (_("Process record: read memeory 0x%s error.\n"),
 				 paddr_nz (i386_record_pc));
 	      return (-1);
 	    }
@@ -2815,7 +2815,7 @@ i386_record_lea_modrm (void)
     {
       if (record_debug)
 	printf_unfiltered (_
-			   ("Record: Record ignore the memory change of instruction in address 0x%s because it can't get the value of the segment register.\n"),
+			   ("Process record ignores the memory change of instruction in address 0x%s because it can't get the value of the segment register.\n"),
 			   paddr_nz (i386_record_pc));
       return (0);
     }
@@ -2852,7 +2852,7 @@ i386_record (struct gdbarch *gdbarch, CO
 
   if (record_debug > 1)
     {
-      fprintf_unfiltered (gdb_stdlog, "Record: i386_record pc = 0x%s\n",
+      fprintf_unfiltered (gdb_stdlog, "Process record: i386_record pc = 0x%s\n",
 			  paddr_nz (i386_record_pc));
     }
 
@@ -2861,7 +2861,7 @@ i386_record (struct gdbarch *gdbarch, CO
     {
       if (target_read_memory (i386_record_pc, &tmpu8, 1))
 	{
-	  printf_unfiltered (_("Record: read memeory 0x%s error.\n"),
+	  printf_unfiltered (_("Process record: read memeory 0x%s error.\n"),
 			     paddr_nz (i386_record_pc));
 	  return (-1);
 	}
@@ -2924,7 +2924,7 @@ reswitch:
     case 0x0f:
       if (target_read_memory (i386_record_pc, &tmpu8, 1))
 	{
-	  printf_unfiltered (_("Record: read memeory 0x%s error.\n"),
+	  printf_unfiltered (_("Process record: read memeory 0x%s error.\n"),
 			     paddr_nz (i386_record_pc));
 	  return (-1);
 	}
@@ -3854,7 +3854,7 @@ reswitch:
 	  {
 	    if (record_debug)
 	      printf_unfiltered (_
-				 ("Record: Record ignore the memory change of instruction in address 0x%s because it can't get the value of the segment register.\n"),
+				 ("Process record ignores the memory change of instruction in address 0x%s because it can't get the value of the segment register.\n"),
 				 paddr_nz (i386_record_pc));
 	  }
 	else
@@ -3873,7 +3873,7 @@ reswitch:
 		    (i386_record_pc, (gdb_byte *) & addr, 4))
 		  {
 		    printf_unfiltered (_
-				       ("Record: read memeory 0x%s error.\n"),
+				       ("Process record: read memeory 0x%s error.\n"),
 				       paddr_nz (i386_record_pc));
 		    return (-1);
 		  }
@@ -3885,7 +3885,7 @@ reswitch:
 		    (i386_record_pc, (gdb_byte *) & tmpu16, 4))
 		  {
 		    printf_unfiltered (_
-				       ("Record: read memeory 0x%s error.\n"),
+				       ("Process record: read memeory 0x%s error.\n"),
 				       paddr_nz (i386_record_pc));
 		    return (-1);
 		  }
@@ -4306,7 +4306,7 @@ reswitch:
 	    /* addr += ((uint32_t)read_register (I386_ES_REGNUM)) << 4; */
             if (record_debug)
 	      printf_unfiltered (_
-			         ("Record: Record ignore the memory change of instruction in address 0x%s because it can't get the value of the segment register.\n"),
+			         ("Process record ignores the memory change of instruction in address 0x%s because it can't get the value of the segment register.\n"),
 			   paddr_nz (i386_record_pc));
 	  }
 
@@ -4728,7 +4728,7 @@ reswitch:
       /* XXX */
     case 0x9b:
       printf_unfiltered (_
-			 ("Record: record and reverse function don't support instruction fwait.\n"));
+			 ("Process record don't support instruction fwait.\n"));
       i386_record_pc -= 1;
       goto no_support;
       break;
@@ -4737,7 +4737,7 @@ reswitch:
       /* XXX */
     case 0xcc:
       printf_unfiltered (_
-			 ("Record: record and reverse function don't support instruction int3.\n"));
+			 ("Process record doesn't support instruction int3.\n"));
       i386_record_pc -= 1;
       goto no_support;
       break;
@@ -4749,7 +4749,7 @@ reswitch:
 	int ret;
 	if (target_read_memory (i386_record_pc, &tmpu8, 1))
 	  {
-	    printf_unfiltered (_("Record: read memeory 0x%s error.\n"),
+	    printf_unfiltered (_("Process record: read memeory 0x%s error.\n"),
 			       paddr_nz (i386_record_pc));
 	    return (-1);
 	  }
@@ -4758,7 +4758,7 @@ reswitch:
 	    || gdbarch_tdep (gdbarch)->i386_intx80_record == NULL)
 	  {
 	    printf_unfiltered (_
-			       ("Record: record and reverse function don't support instruction int 0x%02x.\n"),
+			       ("Process record doesn't support instruction int 0x%02x.\n"),
 			       tmpu8);
 	    i386_record_pc -= 2;
 	    goto no_support;
@@ -4775,7 +4775,7 @@ reswitch:
       /* XXX */
     case 0xce:
       printf_unfiltered (_
-			 ("Record: record and reverse function don't support instruction into.\n"));
+			 ("Process record doesn't support instruction into.\n"));
       i386_record_pc -= 1;
       goto no_support;
       break;
@@ -4789,7 +4789,7 @@ reswitch:
       /* bound */
     case 0x62:
       printf_unfiltered (_
-			 ("Record: record and reverse function don't support instruction bound.\n"));
+			 ("Process record doesn't support instruction bound.\n"));
       i386_record_pc -= 1;
       goto no_support;
       break;
@@ -4831,7 +4831,7 @@ reswitch:
       /* wrmsr */
     case 0x0f30:
       printf_unfiltered (_
-			 ("Record: record and reverse function don't support instruction wrmsr.\n"));
+			 ("Process record doesn't support instruction wrmsr.\n"));
       i386_record_pc -= 2;
       goto no_support;
       break;
@@ -4839,7 +4839,7 @@ reswitch:
       /* rdmsr */
     case 0x0f32:
       printf_unfiltered (_
-			 ("Record: record and reverse function don't support instruction rdmsr.\n"));
+			 ("Process record doesn't support instruction rdmsr.\n"));
       i386_record_pc -= 2;
       goto no_support;
       break;
@@ -4847,7 +4847,7 @@ reswitch:
       /* rdtsc */
     case 0x0f31:
       printf_unfiltered (_
-			 ("Record: record and reverse function don't support instruction rdtsc.\n"));
+			 ("Process record doesn't support instruction rdtsc.\n"));
       i386_record_pc -= 2;
       goto no_support;
       break;
@@ -4859,7 +4859,7 @@ reswitch:
 	if (gdbarch_tdep (gdbarch)->i386_sysenter_record == NULL)
 	  {
 	    printf_unfiltered (_
-			       ("Record: record and reverse function don't support instruction sysenter.\n"));
+			       ("Process record doesn't support instruction sysenter.\n"));
 	    i386_record_pc -= 2;
 	    goto no_support;
 	  }
@@ -4874,7 +4874,7 @@ reswitch:
       /* sysexit */
     case 0x0f35:
       printf_unfiltered (_
-			 ("Record: record and reverse function don't support instruction sysexit.\n"));
+			 ("Process record doesn't support instruction sysexit.\n"));
       i386_record_pc -= 2;
       goto no_support;
       break;
@@ -4902,7 +4902,7 @@ reswitch:
       /* hlt */
     case 0xf4:
       printf_unfiltered (_
-			 ("Record: record and reverse function don't support instruction hlt.\n"));
+			 ("Process record doesn't support instruction hlt.\n"));
       i386_record_pc -= 1;
       goto no_support;
       break;
@@ -4979,7 +4979,7 @@ reswitch:
 	      {
 		if (record_debug)
 		  printf_unfiltered (_
-				     ("Record: Record ignore the memory change of instruction in address 0x%s because it can't get the value of the segment register.\n"),
+				     ("Process record ignores the memory change of instruction in address 0x%s because it can't get the value of the segment register.\n"),
 				     paddr_nz (i386_record_pc));
 error("3");
 	      }
@@ -5030,7 +5030,7 @@ error("3");
 		{
 		  if (record_debug)
 		    printf_unfiltered (_
-				       ("Record: Record ignore the memory change of instruction in address 0x%s because it can't get the value of the segment register.\n"),
+				       ("Process record ignores the memory change of instruction in address 0x%s because it can't get the value of the segment register.\n"),
 				       paddr_nz (i386_record_pc));
 		}
 	      else
@@ -5249,7 +5249,7 @@ error("3");
 
 no_support:
   printf_unfiltered (_
-		     ("Record: record and reverse function don't support instruction 0x%02x at address 0x%s.\n"),
+		     ("Process record doesn't support instruction 0x%02x at address 0x%s.\n"),
 		     (unsigned int) (opcode), paddr_nz (i386_record_pc));
   return (-1);
 }
--- a/inflow.c
+++ b/inflow.c
@@ -598,7 +598,7 @@ kill_command (char *arg, int from_tty)
     error (_("The program is not being run."));
   if (RECORD_IS_USED)
     {
-      if (!query ("Stop the record target and kill the program being debugged? "))
+      if (!query ("Stop the process record target and kill the program being debugged? "))
         error (_("Not confirmed."));
     }
   else
--- a/linux-record.c
+++ b/linux-record.c
@@ -1,4 +1,4 @@
-/* Record and reverse target code for GNU/Linux.
+/* Process record and reply target code for GNU/Linux.
 
    Copyright (C) 2008 Free Software Foundation, Inc.
 
--- a/linux-record.h
+++ b/linux-record.h
@@ -1,4 +1,4 @@
-/* Record and reverse target code for GNU/Linux.
+/* Process record and reply target code for GNU/Linux.
 
    Copyright (C) 2008 Free Software Foundation, Inc.
 
--- a/record.h
+++ b/record.h
@@ -1,4 +1,4 @@
-/* Record and reverse target for GDB, the GNU debugger.
+/* Process record and reply target for GDB, the GNU debugger.
 
    Copyright (C) 2008 Free Software Foundation, Inc.
 

Index Nav: [Date Index] [Subject Index] [Author Index] [Thread Index]
Message Nav: [Date Prev] [Date Next] [Thread Prev] [Thread Next]
--- a/infrun.c
+++ b/infrun.c
@@ -1218,9 +1218,9 @@ proceed (CORE_ADDR addr, enum target_sig
   if (step < 0)
     stop_after_trap = 1;
 
-  /* When GDB resume the inferior, record target doesn't need to record the
-     memory and register store operation of GDB. So set record_not_record to
-     1. */
+  /* When GDB resume the inferior, process record target doesn't need to
+     record the memory and register store operation of GDB. So set
+     record_not_record to 1. */
   if (RECORD_IS_USED)
     record_not_record_set ();
 
@@ -2634,11 +2634,11 @@ targets should add new threads to the th
          be necessary for call dummies on a non-executable stack on
          SPARC.  */
 
-      /* When execution direction is reverse or record target is used, maybe
-         GDB will set next resume to step. Then the next step will be set to
-         random signal. It will make GDB stop the stop the inferior. So When
-         execution direction is reverse or record target is used, not set the 
-         random signal. */
+      /* When execution direction is reverse or process record target is used,
+         maybe GDB will set next resume to step. Then the next step will be
+         set to random signal. It will make GDB stop the stop the inferior. So
+         When execution direction is reverse or record target is used, not set
+         the random signal. */
 
       if (stop_signal == TARGET_SIGNAL_TRAP)
 	ecs->random_signal
@@ -3190,11 +3190,11 @@ infrun: BPSTAT_WHAT_SET_LONGJMP_RESUME (
 	          insert_step_resume_breakpoint_at_sal (sr_sal, null_frame_id);
 		}
 	    }
-	  /* If record target is recording and real running target doesn't
-             support record wait, Record target need execute single instruction
-             for each step to call funtion "record_message" for each
-             instruction. So set "reverse_resume_need_step" to execute single
-             step. */
+	  /* If process record target is recording and real running target
+	     doesn't support record wait, Record target need execute single
+	     instruction for each step to call funtion "record_message" for
+	     each instruction. So set "reverse_resume_need_step" to execute
+	     single step. */
 	  else if (RECORD_IS_USED && !RECORD_IS_REPLAY
                    && !RECORD_TARGET_SUPPORT_RECORD_WAIT)
 	    {
@@ -3281,9 +3281,9 @@ infrun: BPSTAT_WHAT_SET_LONGJMP_RESUME (
 	      insert_step_resume_breakpoint_at_sal (sr_sal, null_frame_id);
 	    }
 	}
-      /* If record target is recording and real running target doesn't
-         support record wait, Record target need execute single instruction
-         for each step to call funtion "record_message" for each
+      /* If process record target is recording and real running target doesn't
+         support record wait, process record target need execute single
+	 instruction for each step to call funtion "record_message" for each
          instruction. So set "reverse_resume_need_step" to execute single
          step. */
       else if (RECORD_IS_USED && !RECORD_IS_REPLAY
@@ -3348,9 +3348,9 @@ infrun: BPSTAT_WHAT_SET_LONGJMP_RESUME (
       if (debug_infrun)
 	 fprintf_unfiltered (gdb_stdlog, "infrun: stepped into undebuggable function\n");
 
-      /* If record target is recording and real running target doesn't
-         support record wait, Record target need execute single instruction
-         for each step to call funtion "record_message" for each
+      /* If process record target is recording and real running target doesn't
+         support record wait, process record target need execute single
+         instruction for each step to call funtion "record_message" for each
          instruction. So set "reverse_resume_need_step" to execute single
          step. */
       if (RECORD_IS_USED && !RECORD_IS_REPLAY
@@ -3431,9 +3431,9 @@ infrun: BPSTAT_WHAT_SET_LONGJMP_RESUME (
 	  return;
 	}
 
-      /* If record target is recording and real running target doesn't
-         support record wait, Record target need execute single instruction
-         for each step to call funtion "record_message" for each
+      /* If process record target is recording and real running target doesn't
+         support record wait, process record target need execute single
+	 instruction for each step to call funtion "record_message" for each
          instruction. So set "reverse_resume_need_step" to execute single
          step. */
       if (RECORD_IS_USED && !RECORD_IS_REPLAY
--- a/record.c
+++ b/record.c
@@ -1,4 +1,4 @@
 /* Record and reverse target for GDB, the GNU debugger.
 
    Copyright (C) 2008 Free Software Foundation, Inc.
 
@@ -202,7 +202,7 @@ record_arch_list_add_reg (int num)
   if (record_debug > 1)
     {
       fprintf_unfiltered (gdb_stdlog,
-			  "Record: add register num = %d to record list.\n", 
+			  "Process record: add register num = %d to record list.\n", 
 			  num);
     }
 
@@ -231,7 +231,7 @@ record_arch_list_add_mem (CORE_ADDR addr
   if (record_debug > 1)
     {
       fprintf_unfiltered (gdb_stdlog,
-			  "Record: add mem addr = 0x%s len = %d to record list.\n",
+			  "Process record: add mem addr = 0x%s len = %d to record list.\n",
 			  paddr_nz (addr), len);
     }
 
@@ -251,7 +251,7 @@ record_arch_list_add_mem (CORE_ADDR addr
   if (target_read_memory (addr, rec->u.mem.val, len))
     {
       fprintf_unfiltered (gdb_stdlog,
-			  "Record: read memory addr = 0x%s len = %d error.\n",
+			  "Process record: read memory addr = 0x%s len = %d error.\n",
 			  paddr_nz (addr), len);
       xfree (rec->u.mem.val);
       xfree (rec);
@@ -272,7 +272,7 @@ record_arch_list_add_end (int need_dasm)
   if (record_debug > 1)
     {
       fprintf_unfiltered (gdb_stdlog,
-			  "Record: add end need_dasm = %d to arch list.\n",
+			  "Process record: add end need_dasm = %d to arch list.\n",
 			  need_dasm);
     }
 
@@ -311,7 +311,7 @@ record_check_insn_num (int set_terminal)
 		}
 	      else
 		{
-		  error (_("Record: record stop the program."));
+		  error (_("Process record: record stop the program."));
 		}
 	    }
 	}
@@ -357,7 +357,7 @@ record_message (struct gdbarch *gdbarch)
       if (record_debug)
 	{
 	  fprintf_unfiltered (gdb_stdlog,
-			      "Record: this stepping is displaced stepping.  Change PC register to original address 0x%s before call gdbarch_record.  After that, change it back to 0x%s.\n",
+			      "Process record: this stepping is displaced stepping.  Change PC register to original address 0x%s before call gdbarch_record.  After that, change it back to 0x%s.\n",
 			      paddr_nz (displaced_step_original),
 			      paddr_nz (displaced_step_copy));
 	}
@@ -371,9 +371,9 @@ record_message (struct gdbarch *gdbarch)
     }
 
   if (ret > 0)
-    error (_("Record: record pause the program."));
+    error (_("Process record pause the program."));
   if (ret < 0)
-    error (_("Record: record message error."));
+    error (_("Process record record message error."));
 
   discard_cleanups (old_cleanups);
 
@@ -411,33 +411,33 @@ record_open (char *name, int from_tty)
 {
   if (record_debug)
     {
-      fprintf_unfiltered (gdb_stdlog, "Record: record_open\n");
+      fprintf_unfiltered (gdb_stdlog, "Process record: record_open\n");
     }
 
   /* check exec */
   if (!target_has_execution)
     {
-      error (_("Record: the program is not being run."));
+      error (_("Process record: the program is not being run."));
     }
   if (non_stop)
     {
-      error (_("Record: record target can't debug inferior in non-stop mode (non-stop)."));
+      error (_("Process record can't debug inferior in non-stop mode (non-stop)."));
     }
   if (record_linux_async_permitted)
     {
-      error (_("Record: record target can't debug the GNU/Linux inferior in asynchronous mode (linux-async)."));
+      error (_("Process record can't debug the GNU/Linux inferior in asynchronous mode (linux-async)."));
     }
 
   if (!gdbarch_record_p (current_gdbarch))
     {
-      error (_("Record: the current architecture doesn't support record function."));
+      error (_("Process record: the current architecture doesn't support process record target."));
     }
 
   /* Check if record target is already running */
   if (RECORD_IS_USED)
     {
       if (!nquery
-	  (_("Record target already running, do you want delete the old record log?")))
+	  (_("Process record target already running, do you want delete the old record log?")))
 	{
 	  return;
 	}
@@ -457,7 +457,7 @@ record_close (int quitting)
 {
   if (record_debug)
     {
-      fprintf_unfiltered (gdb_stdlog, "Record: record_close\n");
+      fprintf_unfiltered (gdb_stdlog, "Process record: record_close\n");
     }
   record_list_release (record_list);
 }
@@ -479,7 +479,7 @@ record_sig_handler (int signo)
 {
   if (record_debug)
     {
-      fprintf_unfiltered (gdb_stdlog, "Record: get a signal\n");
+      fprintf_unfiltered (gdb_stdlog, "Process record: get a signal\n");
     }
   record_resume_step = 1;
   record_get_sig = 1;
@@ -513,7 +513,7 @@ record_wait (ptid_t ptid, struct target_
   if (record_debug)
     {
       fprintf_unfiltered (gdb_stdlog,
-			  "Record: record_wait record_resume_step = %d\n",
+			  "Process record: record_wait record_resume_step = %d\n",
 			  record_resume_step);
     }
 
@@ -536,7 +536,7 @@ record_wait (ptid_t ptid, struct target_
       act.sa_flags = SA_RESTART;
       if (sigaction (SIGINT, &act, &old_act))
 	{
-	  perror_with_name (_("Record: sigaction"));
+	  perror_with_name (_("Process record: sigaction"));
 	}
       /* If GDB is in terminal_inferior, it will not get the signal.
          And in GDB replay mode, GDB don't need to in terminal_inferior
@@ -579,7 +579,7 @@ record_wait (ptid_t ptid, struct target_
 	      if (record_debug > 1)
 		{
 		  fprintf_unfiltered (gdb_stdlog,
-				      "Record: record_reg 0x%s to inferior num = %d.\n",
+				      "Process record: record_reg 0x%s to inferior num = %d.\n",
 				      paddr_nz ((CORE_ADDR)record_list),
 				      record_list->u.reg.num);
 		}
@@ -595,7 +595,7 @@ record_wait (ptid_t ptid, struct target_
 	      if (record_debug > 1)
 		{
 		  fprintf_unfiltered (gdb_stdlog,
-				      "Record: record_mem 0x%s to inferior addr = 0x%s len = %d.\n",
+				      "Process record: record_mem 0x%s to inferior addr = 0x%s len = %d.\n",
 				      paddr_nz ((CORE_ADDR)record_list),
 				      paddr_nz (record_list->u.mem.addr),
 				      record_list->u.mem.len);
@@ -603,7 +603,7 @@ record_wait (ptid_t ptid, struct target_
 	      if (target_read_memory
 		  (record_list->u.mem.addr, mem, record_list->u.mem.len))
 		{
-		  error (_("Record: read memory addr = 0x%s len = %d error."),
+		  error (_("Process record: read memory addr = 0x%s len = %d error."),
 			 paddr_nz (record_list->u.mem.addr),
 			 record_list->u.mem.len);
 		}
@@ -612,7 +612,7 @@ record_wait (ptid_t ptid, struct target_
 		   record_list->u.mem.len))
 		{
 		  error (_
-			 ("Record: write memory addr = 0x%s len = %d error."),
+			 ("Process record: write memory addr = 0x%s len = %d error."),
 			 paddr_nz (record_list->u.mem.addr),
 			 record_list->u.mem.len);
 		}
@@ -627,7 +627,7 @@ record_wait (ptid_t ptid, struct target_
 	      if (record_debug > 1)
 		{
 		  fprintf_unfiltered (gdb_stdlog,
-				      "Record: record_end 0x%s to inferior need_dasm = %d.\n",
+				      "Process record: record_end 0x%s to inferior need_dasm = %d.\n",
 				      paddr_nz ((CORE_ADDR)record_list),
 				      record_list->u.need_dasm);
 		}
@@ -658,7 +658,7 @@ record_wait (ptid_t ptid, struct target_
 		    {
 		      if (record_debug > 1)
 			{
-			  fprintf_unfiltered (gdb_stdlog, "Record: step.\n");
+			  fprintf_unfiltered (gdb_stdlog, "Process record: step.\n");
 			}
 		      continue_flag = 0;
 		    }
@@ -687,7 +687,7 @@ record_wait (ptid_t ptid, struct target_
 			  if (record_debug)
 			    {
 			      fprintf_unfiltered (gdb_stdlog,
-						  "Record: break at 0x%s.\n",
+						  "Process record: break at 0x%s.\n",
 						  paddr_nz (tmp_pc));
 			    }
 			  continue_flag = 0;
@@ -720,7 +720,7 @@ next:
 
       if (sigaction (SIGALRM, &old_act, NULL))
 	{
-	  perror_with_name (_("Record: sigaction"));
+	  perror_with_name (_("Process record: sigaction"));
 	}
 
       if (record_get_sig)
@@ -743,7 +743,7 @@ record_disconnect (struct target_ops *ta
 {
   if (record_debug)
     {
-      fprintf_unfiltered (gdb_stdlog, "Record: record_disconnect\n");
+      fprintf_unfiltered (gdb_stdlog, "Process record: record_disconnect\n");
     }
   unpush_target (&record_ops);
   target_disconnect (args, from_tty);
@@ -754,7 +754,7 @@ record_detach (char *args, int from_tty)
 {
   if (record_debug)
     {
-      fprintf_unfiltered (gdb_stdlog, "Record: record_detach\n");
+      fprintf_unfiltered (gdb_stdlog, "Process record: record_detach\n");
     }
   unpush_target (&record_ops);
   target_detach (args, from_tty);
@@ -765,19 +765,19 @@ record_mourn_inferior (void)
 {
   if (record_debug)
     {
-      fprintf_unfiltered (gdb_stdlog, "Record: record_mourn_inferior\n");
+      fprintf_unfiltered (gdb_stdlog, "Process record: record_mourn_inferior\n");
     }
   unpush_target (&record_ops);
   target_mourn_inferior ();
 }
 
-/* Close record target before kill the inferior process.  */
+/* Close process record target before kill the inferior process.  */
 static void
 record_kill (void)
 {
   if (record_debug)
     {
-      fprintf_unfiltered (gdb_stdlog, "Record: record_kill\n");
+      fprintf_unfiltered (gdb_stdlog, "Process record: record_kill\n");
     }
   unpush_target (&record_ops);
   target_kill ();
@@ -803,7 +803,7 @@ record_registers_change (struct regcache
 	  if (record_arch_list_add_reg (i))
 	    {
 	      record_list_release (record_arch_list_tail);
-	      error (_("Record: record message error."));
+	      error (_("Process record: record message error."));
 	    }
 	}
     }
@@ -812,13 +812,13 @@ record_registers_change (struct regcache
       if (record_arch_list_add_reg (regnum))
 	{
 	  record_list_release (record_arch_list_tail);
-	  error (_("Record: record message error."));
+	  error (_("Process record: record message error."));
 	}
     }
   if (record_arch_list_add_end (0))
     {
       record_list_release (record_arch_list_tail);
-      error (_("Record: record message error."));
+      error (_("Process record: record message error."));
     }
   record_list->next = record_arch_list_head;
   record_arch_list_head->prev = record_list;
@@ -851,7 +851,7 @@ record_prepare_to_store (struct regcache
 					      (regcache),
 					      record_regcache_raw_write_regnum)))
 	    {
-	      error (_("Record: record cancel the operation."));
+	      error (_("Process record: record cancel the operation."));
 	    }
 
 	  /* Destroy the record from here forward.  */
@@ -898,13 +898,13 @@ record_xfer_partial (struct target_ops *
       if (record_arch_list_add_mem (offset, len))
 	{
 	  record_list_release (record_arch_list_tail);
-	  fprintf_unfiltered (gdb_stdlog, _("Record: record message error."));
+	  fprintf_unfiltered (gdb_stdlog, _("Process record: record message error."));
 	  return -1;
 	}
       if (record_arch_list_add_end (0))
 	{
 	  record_list_release (record_arch_list_tail);
-	  fprintf_unfiltered (gdb_stdlog, _("Record: record message error."));
+	  fprintf_unfiltered (gdb_stdlog, _("Process record: record message error."));
 	  return -1;
 	}
       record_list->next = record_arch_list_head;
@@ -956,7 +956,7 @@ static enum exec_direction_kind
 record_get_execdir (void)
 {
   if (record_debug > 1)
-    printf_filtered ("Record: execdir is %s\n",
+    printf_filtered ("Process record: execdir is %s\n",
 		     record_execdir == EXEC_FORWARD ? "forward" :
 		     record_execdir == EXEC_REVERSE ? "reverse" : "unknown");
   return record_execdir;
@@ -966,7 +966,7 @@ static int
 record_set_execdir (enum exec_direction_kind dir)
 {
   if (record_debug)
-    printf_filtered ("Record: set execdir: %s\n",
+    printf_filtered ("Process record: set execdir: %s\n",
 		     dir == EXEC_FORWARD ? "forward" :
 		     dir == EXEC_REVERSE ? "reverse" : "bad direction");
 
@@ -981,7 +981,7 @@ static void
 init_record_ops (void)
 {
   record_ops.to_shortname = "record";
-  record_ops.to_longname = "Record and reverse target";
+  record_ops.to_longname = "Process record and reply target";
   record_ops.to_doc =
     "Log program while executing and replay execution from log.";
   record_ops.to_open = record_open;
@@ -1007,7 +1007,7 @@ static void
 show_record_debug (struct ui_file *file, int from_tty,
 		   struct cmd_list_element *c, const char *value)
 {
-  fprintf_filtered (file, _("Debugging of record target is %s.\n"), value);
+  fprintf_filtered (file, _("Debugging of process record target is %s.\n"), value);
 }
 
 /* cmd_record_start -- alias for "target record".  */
@@ -1028,20 +1028,20 @@ cmd_record_delete (char *args, int from_
     {
       if (RECORD_IS_REPLAY)
 	{
-	  if (!from_tty || query (_("Record: delete the log from this point forward and begin to record the running message at current PC?")))
+	  if (!from_tty || query (_("Process record: delete the log from this point forward and begin to record the running message at current PC?")))
 	    {
 	      record_list_release_next ();
 	    }
 	}
       else
 	{
-	  printf_unfiltered (_("Record: already at end of record list.\n"));
+	  printf_unfiltered (_("Process record: already at end of record list.\n"));
 	}
 
     }
   else
     {
-      printf_unfiltered (_("Record: record target is not started.\n"));
+      printf_unfiltered (_("Process record is not started.\n"));
     }
 }
 
@@ -1052,14 +1052,14 @@ cmd_record_stop (char *args, int from_tt
 {
   if (RECORD_IS_USED)
     {
-      if (!record_list || !from_tty || query (_("Record: delete recorded log and stop recording?")))
+      if (!record_list || !from_tty || query (_("Process record: delete recorded log and stop recording?")))
 	{
 	  unpush_target (&record_ops);
 	}
     }
   else
     {
-      printf_unfiltered (_("Record: record target is not started.\n"));
+      printf_unfiltered (_("Process record is not started.\n"));
     }
 }
 
@@ -1070,7 +1070,7 @@ set_record_insn_max_num (char *args, int
 {
   if (record_insn_num > record_insn_max_num && record_insn_max_num)
     {
-      printf_unfiltered (_("Record: record instructions number is bigger than record instructions max number.  Auto delete the first ones.\n"));
+      printf_unfiltered (_("Process record: record instructions number is bigger than record instructions max number.  Auto delete the first ones.\n"));
 
       while (record_insn_num > record_insn_max_num)
 	{
@@ -1095,7 +1095,7 @@ _initialize_record (void)
   /* Init record_maskall.  */
   if (sigfillset (&record_maskall) == -1)
     {
-      perror_with_name (_("Record: sigfillset"));
+      perror_with_name (_("Process record: sigfillset"));
     }
 
   /* Init record_first.  */
@@ -1125,7 +1125,7 @@ _initialize_record (void)
      other affect to GDB such as call function "no_shared_libraries".
      So I add special commands to GDB.  */
   add_com ("delrecord", class_obscure, cmd_record_delete,
-	   _("When record target running in replay mode, delete the next running messages and begin to record the running message at current address."));
+	   _("When process record target running in replay mode, delete the next running messages and begin to record the running message at current address."));
   add_com_alias ("dr", "delrecord", class_obscure, 1);
   add_com ("stoprecord", class_obscure, cmd_record_stop,
 	   _("Stop the record/replay target."));
@@ -1,4 +1,4 @@
-/* Record and reverse target for GDB, the GNU debugger.
+/* Process record and reply target for GDB, the GNU debugger.
 
    Copyright (C) 2008 Free Software Foundation, Inc.
@@ -411,33 +411,33 @@ record_open (char *name, int from_tty)
     }
 
-  /* Check if record target is already running */
+  /* Check if process record target is already running */
   if (RECORD_IS_USED)
     {